@@ -1,7 +1,7 @@
 package RSS::From::Twitter;
 
-our $DATE = '2015-08-18'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2015-09-04'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use 5.010001;
 use strict;
@@ -267,7 +267,7 @@ RSS::From::Twitter - Convert Twitter page to RSS
 
 =head1 VERSION
 
-This document describes version 0.06 of RSS::From::Twitter (from Perl distribution RSS-From-Twitter), released on 2015-08-18.
+This document describes version 0.07 of RSS::From::Twitter (from Perl distribution RSS-From-Twitter), released on 2015-09-04.
 
 =head1 SYNOPSIS
 
@@ -278,9 +278,8 @@ This document describes version 0.06 of RSS::From::Twitter (from Perl distributi
 
 =head2 get_rss_from_twitter(%args) -> [status, msg, result, meta]
 
-{en_US Convert Twitter page to RSS}.
+Convert Twitter page to RSS.
 
-{en_US 
 In June 2013, Twitter retired the RSS v1 API (e.g.
 http://search.twitter.com/search.rss?q=blah, etc). However, its replacement, the
 v1.1 API, is not as straightforward to use (e.g. needs auth). This function
@@ -289,7 +288,6 @@ and converts it to RSS. I wrote this because I have other scripts expecting RSS
 input.
 
 Expect breakage from time to time though, as scraping method is rather fragile.
-}
 
 Arguments ('*' denotes required arguments):
 
@@ -297,19 +295,17 @@ Arguments ('*' denotes required arguments):
 
 =item * B<title> => I<str>
 
-{en_US RSS title}.
+RSS title.
 
 =item * B<ua> => I<obj>
 
-{en_US Supply a custom LWP::UserAgent object}.
+Supply a custom LWP::UserAgent object.
 
-{en_US 
 If supplied, will be used instead of the default LWP::UserAgent object.
-}
 
 =item * B<url>* => I<str>
 
-{en_US URL, e.g. https://twitter.com/foo or file:/test.html}.
+URL, e.g. https://twitter.com/foo or file:/test.html.
 
 =back
 
@@ -327,12 +323,10 @@ Return value:  (any)
 
 =head2 get_rss_from_twitter_list(%args) -> [status, msg, result, meta]
 
-{en_US Convert Twitter public list page to RSS}.
+Convert Twitter public list page to RSS.
 
-{en_US 
 This function calls get_rss_from_twitter() with URL:
 C<https//twitter.com/USERNAME/LISTNAME>.
-}
 
 Arguments ('*' denotes required arguments):
 
@@ -340,19 +334,17 @@ Arguments ('*' denotes required arguments):
 
 =item * B<listname>* => I<str>
 
-{en_US User's list name}.
+User's list name.
 
 =item * B<ua> => I<obj>
 
-{en_US Supply a custom LWP::UserAgent object}.
+Supply a custom LWP::UserAgent object.
 
-{en_US 
 If supplied, will be used instead of the default LWP::UserAgent object.
-}
 
 =item * B<username>* => I<str>
 
-{en_US Twitter username}.
+Twitter username.
 
 =back
 
@@ -370,12 +362,10 @@ Return value:  (any)
 
 =head2 get_rss_from_twitter_search(%args) -> [status, msg, result, meta]
 
-{en_US Convert Twitter search result page to RSS}.
+Convert Twitter search result page to RSS.
 
-{en_US 
 This function calls get_rss_from_twitter() with URL:
 C<https//twitter.com/search?q=QUERY>.
-}
 
 Arguments ('*' denotes required arguments):
 
@@ -383,15 +373,13 @@ Arguments ('*' denotes required arguments):
 
 =item * B<query>* => I<str>
 
-{en_US Search query}.
+Search query.
 
 =item * B<ua> => I<obj>
 
-{en_US Supply a custom LWP::UserAgent object}.
+Supply a custom LWP::UserAgent object.
 
-{en_US 
 If supplied, will be used instead of the default LWP::UserAgent object.
-}
 
 =back
 
@@ -409,12 +397,10 @@ Return value:  (any)
 
 =head2 get_rss_from_twitter_user(%args) -> [status, msg, result, meta]
 
-{en_US Convert Twitter user main page to RSS}.
+Convert Twitter user main page to RSS.
 
-{en_US 
 This function calls get_rss_from_twitter() with URL:
 C<https//twitter.com/USERNAME>.
-}
 
 Arguments ('*' denotes required arguments):
 
@@ -422,15 +408,13 @@ Arguments ('*' denotes required arguments):
 
 =item * B<ua> => I<obj>
 
-{en_US Supply a custom LWP::UserAgent object}.
+Supply a custom LWP::UserAgent object.
 
-{en_US 
 If supplied, will be used instead of the default LWP::UserAgent object.
-}
 
 =item * B<username>* => I<str>
 
-{en_US Twitter username}.
+Twitter username.
 
 =back
 
